<?php
/**
 * @package	Google Core Web Vitals Fix
 * @copyright	Copyright (C) 2020 SiteGuarding.com. All rights reserved.
 * @GNU General Public License
 */

defined( '_JEXEC' ) or die;

ini_set("display_errors", "Off");

define('plggcwvf_UPGRADE_LINK', 'https://www.siteguarding.com/en/buy-service/google-core-web-vitals-fix-services'); 


if (version_compare(JVERSION, '3.0', '<'))
{
	if (JFactory::getApplication()->get('jquery') !== true)
	{
		// Load jQuery in no conflict mode with B/C support
		JHtml::script('../media/com_webvitals/jquery.min.js');
		JHtml::script('../media/com_webvitals/jquery-migrate.min.js');
		JHtml::script('../media/com_webvitals/jquery-noconflict.js');
		JFactory::getApplication()->set('jquery', true);
	}
}
else
{
JHtml::_('jquery.framework'); // load jquery
//JHtml::_('jquery.ui');
}

$document = JFactory::getDocument();
$document->addStyleSheet('../media/com_webvitals/semantic.min.css');
$document->addScript('../media/com_webvitals/semantic.min.js');
$document->addScript('../media/com_webvitals/javascript.js');

include_once('functions.php');

JToolBarHelper::title( JText::_( 'Google Core Web Vitals Fix' ));

		plggcwvf_TemplateHeader($title = 'Google Core Web Vitals Fix');

		if (PHP_MAJOR_VERSION == 4) {
			plggcwvf_error('Not supported PHP version');
			return false;
		}

		if (is_int(PHP_MAJOR_VERSION) && is_int(PHP_MINOR_VERSION) && PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION == 2) {
			plggcwvf_error('PHP 5.2.x is Not supported anymore, due to security issues.');
			return false;
		}
		
		$extensions = get_loaded_extensions();
		if (!plggcwvf_check_ioncube_version()) {
			plggcwvf_error('IonCube Loader version 10 or higher is required for this plugin.');
			return false;
		}
		
	    $action = '';
        if (isset($_REQUEST['action'])) $action = trim($_REQUEST['action']);
        
        // Actions
        if ($action != '')
        {
            $action_message = '';
            switch ($action)
            {
					
                case 'Save_Settings':

					$data = array();
					$action_type = 'ok';
					$data['plggcwvf_status'] = intval($_POST['plggcwvf_status']);
					$action_message = 'Settings saved';
					plggcwvf_Set_Params($data);
					if ($data['plggcwvf_status']) {
						$license = plggcwvf_get_licence_info();
						if ($license === true) {
							plggcwvf_PatchJMIndex_file(true);
						} else {
							$action_message = $license;
							$action_type = 'alert';
						}
						
					} else {
						plggcwvf_PatchJMIndex_file(false);
					}

                    break;
            }
            
            if ($action_message != '')
            {
                $message_data = array(
                    'type' => $action_type,
                    'header' => '',
                    'message' => $action_message,
                    'button_text' => '',
                    'button_url' => '',
                    'help_text' => ''
                );
                plggcwvf_PrintIconMessage($message_data);
            }
        }
		
		if (is_file(dirname(__FILE__) . '/terminated.flag'))
		{
			$message_data = array(
				'type' => 'alert',
				'header' => '',
				'message' => 'Something is wrong with your license or it has expired. Enable improvement again to update license info or purchase our paid license.',
				'button_text' => '',
				'button_url' => '',
				'help_text' => ''
			);
			plggcwvf_PrintIconMessage($message_data);
		}
		

		$params = plggcwvf_Get_Params();
		$php_version = plggcwvf_get_php_version();
		
		if (!is_file(dirname(__FILE__) . '/license.json') || !is_file(dirname(__FILE__) . '/core.web.vitals.main.'.$php_version.'.php') || !$params['plggcwvf_status']) {
			$params['plggcwvf_status'] = 0;
			plggcwvf_Set_Params($params);
			plggcwvf_PatchJMIndex_file(false);
			@unlink(dirname(__FILE__) . '/license.json');
			@unlink(dirname(__FILE__) . '/core.web.vitals.main.'.$php_version.'.php');
		}
		
		$exp_date = plggcwvf_get_exp_date();
		
		$status = $params['plggcwvf_status'] ? '<span class="green ui label">Enabled</span>' : '<span class="red ui label">Disabled</span>';
		$status_css = $params['plggcwvf_status'] ? '' : 'disabled';

	    ?>
		
<div class="ui icon info message">
  <i class="info circle icon"></i>
  <div class="content">
    <div class="header">
      Disclaimer
    </div>
    <p>This version of the plugin shows the improvements you can get by optimizing your site for Google Core Web Vitals. It does not make any changes in the WordPress CMS core and does not optimize JavaScript or CSS files it only performs basic optimization. <b>All the changes should be done manually.</b></p>
    <p>Please note, WordPress has 100 000+ different themes and plugins and it is not possible to create an automated solution that can optimize all plugins and themes. Google Core Web Vital optimization is a 100% manual work and <b>should be done by professional engineers.</b></p>
    <p>Our plugin performs the website performance check and shows you if we can help you get better results for Google and improve your website performance.</p>
  </div>
</div>



<h3 class="ui dividing header">Current status <?php echo $status; ?></h3>
<?php if ($exp_date) : ?>
Valid till: <b><?php echo $exp_date; ?></b>
<?php endif; ?>
		<div class="ui basic center aligned segment">
        <form method="post" action="index.php?option=com_webvitals" class="ui form">
        
	  
		<?php

        
        if ($params['plggcwvf_status']) {
            ?>
            <input type="submit" name="submit" class="negative ui big button" value="Disable Improvement">
            <input type="hidden" name="plggcwvf_status" value="0">
            <?php
        }
        else {
            ?>
            <input type="submit" name="submit" class="positive ui big button" value="Enable Improvement">
            <input type="hidden" name="plggcwvf_status" value="1">
            <?php
        }
		?>   
        
				 <input type="hidden" name="action"  value="Save_Settings">
        </form>
        </div>
      
<h3 class="ui dividing header">Parameters for Improvement <?php echo $status?></h3>  

<div class="ui info message">
  <p><b>Please note:</b> This plugin performs basic automated optimization and can not optimize the code if you need a full optimization, our engineers can help you. Please note, Google Core Web Vitals optimization is 100% manual work and should be done by professionals.</p>
</div>
        
<div class="ui grid">
  <div class="four wide column">
    <div class="ui center aligned secondary segment <?php echo $status_css; ?>">
      <?php
      if ($status_css == '') echo '<div class="floating ui green label">OK</div>';
      ?>
      <i class="code big icon"></i><br />
      <h3 class="ui header">JavaScript</h3>
      <p>Optimization of JS codes</p>
    </div>
  </div>
  <div class="four wide column">
    <div class="ui center aligned secondary segment <?php echo $status_css; ?>">
      <?php
      if ($status_css == '') echo '<div class="floating ui green label">OK</div>';
      ?>
      <i class="file code big icon"></i><br />
      <h3 class="ui header">CSS</h3>
      <p>Optimization of CSS codes</p>
    </div>
  </div>
  <div class="four wide column">
    <div class="ui center aligned secondary segment <?php echo $status_css; ?>">
      <?php
      if ($status_css == '') echo '<div class="floating ui green label">OK</div>';
      ?>
      <i class="upload big icon"></i><br />
      <h3 class="ui header">Output Compressing</h3>
      <p>Optimization of data transfer</p>
    </div>
  </div>
  <div class="four wide column">
    <div class="ui center aligned secondary segment <?php echo $status_css; ?>">
      <?php
      if ($status_css == '') echo '<div class="floating ui green label">OK</div>';
      ?>
      <i class="plug big icon"></i><br />
      <h3 class="ui header">Queries</h3>
      <p>Optimization amount of queries</p>
    </div>
  </div>
</div>
		

<div class="ui basic center aligned segment">
    <a target="_blank" class="ui big button" href="https://googlechrome.github.io/lighthouse/viewer/?psiurl=<?php echo JURI::root(); ?>&strategy=mobile&category=performance&category=accessibility&category=best-practices&category=seo&category=pwa&utm_source=lh-chrome-ext">Check My Website!</a>
    <a target="_blank" class="positive ui big button" href="<?php echo plggcwvf_UPGRADE_LINK; ?>">Upgrade to Premium</a>
    
    <br /><br />
    
    Check your website results with enabled and disabled status to see the difference in improvement.
</div>


<h3 class="ui dividing header">Premium Support Includes</h3> 

    <div class="ui list">

            <a class="item"><i class="check icon green"></i><div class="content"><div class="description">100% manual code optimization (to get better score results)</div></div></a>
            <a class="item"><i class="check icon green"></i><div class="content"><div class="description">Google Fix Validation (we will prepare your website to pass validation and will send all necessary requests to Google)</div></div></a>
            <a class="item"><i class="check icon green"></i><div class="content"><div class="description">JavaScript optimization (to get better score results)</div></div></a>
            <a class="item"><i class="check icon green"></i><div class="content"><div class="description">CSS optimization (to get better score results)</div></div></a>
            <a class="item"><i class="check icon green"></i><div class="content"><div class="description">24/7 support & Live Chat support</div></div></a>
            <a class="item"><i class="check icon green"></i><div class="content"><div class="description">Google Revision Request</div></div></a>
            <a class="item"><i class="check icon green"></i><div class="content"><div class="description">Full security for the website (monitoring, malware removal, antivirus, firewall (WAF))</div></div></a>

    </div>
    <a target="_blank" class="ui small button" href="https://www.siteguarding.com/en/google-core-web-vitals-fix">Service Details</a>		 
    <a target="_blank" class="positive ui small button" href="<?php echo plggcwvf_UPGRADE_LINK; ?>">Get Premium</a>		


        


        
        
        <?php
        plggcwvf_BottomHeader();
